California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 046 - DRUG AND ALCOHOL TESTING OF DOCTORS. MEDICAL NEGLIGENCE LAWSUITS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1362225 | YES ON PROP 46, FAMILIES FOR PATIENT SAFETY | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1365833 | CALIFORNIANS ALLIED FOR PATIENT PROTECTION BALLOT MEASURE COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1367047 | CALIFORNIA ASSOCIATION OF HEALTH FACILITIES, DEFEND MICRA ON THE NOVEMBER BALLOT COMMITTEE, NO ON 46 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1361562 | YES ON PROP. 46, YOUR NEIGHBORS FOR PATIENT SAFETY, A COALITION OF CONSUMER ATTORNEYS AND PATIENT SAFETY ADVOCATES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1336069 | CONSUMER WATCHDOG CAMPAIGN - YES ON 45 AND 46, A COALITION OF CONSUMER ADVOCATES, ATTORNEYS AND NURSES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1359222 | NO ON 46 - PATIENTS, PROVIDERS AND HEALTHCARE INSURERS TO CONTAIN HEALTH COSTS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1369500 | CONSUMER WATCHDOG CAMPAIGN - YES ON 46, A COALITION OF ATTORNEYS, CONSUMER ADVOCATES, AND PATIENTS | SUPPORT